<?php

Route::post('/account/v1/authenticate', 'Account@authenticate');

Route::post('/account/v1',              'Account@create');
Route::get('/account/v1/{id}',          'Account@read');
Route::put('/account/v1/{id}',          'Account@update');
Route::delete('/account/v1/{id}',       'Account@delete');