<?php

namespace AuthStack\UserDirectory\Http\Controllers;

use AuthStack\UserDirectory\Model\Organization as OrganizationModel;

class Organization extends Controller
{
    public function listing()
    {
    }

    public function create()
    {}

    public function update()
    {}

    public function read($id)
    {}

    public function delete($id)
    {}

    /**
     * Loads the organization from database as Eloquent model
     *
     * @param $id
     * @return OrganizationModel
     */
    public function organization($id): OrganizationModel
    {
        return (new OrganizationModel())->findOrFail($id);
    }
}
