<?php

use Illuminate\Support\Facades\Schema;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Database\Migrations\Migration;

class CreateAccountsStatusesTable extends Migration
{
    public function up()
    {
        Schema::create('accounts_statuses', function(Blueprint $table)
        {
            $table->primary('id')->unsigned();
            $table->string('title', 255);
            $table->string('description')->nullable();
            $table->timestamps();
        });
    }

    public function down()
    {
        Schema::disableForeignKeyConstraints();
        Schema::dropIfExists('accounts_statuses');
    }
}